/**
 * The abstract class encapsulates information about chocolate. 
 * @author Andriyp
 *
 */
public abstract class Chocolate {
	protected double weight = 100.0;
	protected String name;
	protected String country;
	protected double cocoaButterPercentage;
	protected double cocoaSolidsPercentage;
	protected double milkFatPercentage;
	protected double milkSolidsPercentage;
	protected double sugarPercentage;
	
	
	/**
	 * A default constructor, creates a 100 gram chocolate bar 
	 */
	public Chocolate(){
		this("unknown", 100, "unknown", 0.0, 0.0, 0.0, 0.0, 0.0);
	}

	/**
	 * Creates a chocolate bar with a specified size with "unknown" name and country
	 * @param weight weigh of the chocolate bar
	 */
	public Chocolate(double weight){
		this("unknown", weight, "unknown", 0.0, 0.0, 0.0, 0.0, 0.0);
	}
	
	/**
	 * Creates a chocolate bar with specified name, size, and country
	 * @param name Name
	 * @param weight bar size in grams
	 * @param country country of manufacturing
	 */
	public Chocolate(String name, double weight, String country){
		this(name, weight, country, 0.0, 0.0, 0.0, 0.0, 0.0);

	}

	/**
	 * Creates a chocolate bar with specified name, size, country, and sugar content
	 * @param name Name
	 * @param weight bar size in grams
	 * @param country country of manufacturing
	 * @param cocoaButterPercentage Percentage of cocoa butter in the chocolate
	 * @param cocoaSolidsPercentage Percentage of cocoa solids in the chocolate
	 * @param milkFatPercentage Percentage of milk fat in the chocolate
	 * @param milkSolidsPercentage Percentage of milk solids in the chocolate
	 * @param sugarPercentage Percentage of sugar in the chocolate
	 */
	public Chocolate(String name, double weight, String country, double cocoaButterPercentage, double cocoaSolidsPercentage,
			double milkFatPercentage, double milkSolidsPercentage, double sugarPercentage){
		this.name = name;
		this.weight = weight;
		this.country = country;
		this.cocoaButterPercentage = cocoaButterPercentage;
		this.cocoaSolidsPercentage = cocoaSolidsPercentage;
		this.milkFatPercentage = milkFatPercentage;
		this.milkSolidsPercentage = milkSolidsPercentage;
		this.sugarPercentage = sugarPercentage;
	}

	/** Returns the weight of the chocolate bar
	 * @return weight of the chocolate bar
	 */
	public double getWeight (){
		return this.weight;
	}
	
	/** Allows setting the weight of the chocolate bar
	 * @param weight weight of the chocolate bar
	 */
	public void setWeight(double weight){
		this.weight = weight;
	}
	
	/** 
	 * Returns a string describing the chocolate 
	 */
	@Override public abstract String toString();
}