/**
 * This class describes dark chocolate (i.e., chocolate made with no milk ingredients added)
 * @author Andriyp
 *
 */
public class DarkChocolate extends Chocolate {

	/**
	 * Creates a typical dark chocolate bar with specified name, size, and country
	 * 35% cocoa butter, 15 % cocoa solids), 50% sugar. 
	 * @param name Name
	 * @param weight bar size in grams
	 * @param country country of manufacturing
	 */
	public DarkChocolate(String name, double weight, String country){
		this(name, weight, country, 35.0, 15.0, 50.0);
	}

	/**
	 * Creates a dark chocolate bar with specified name, size, country and other ingredients
	 * @param name Name
	 * @param weight bar size in grams
	 * @param country country of manufacturing
	 * @param cocoaButterPercentage Percentage of cocoa butter in the chocolate
	 * @param cocoaSolidsPercentage Percentage of cocoa solids in the chocolate
	 * @param sugarPercentage Percentage of sugar in the chocolate
	 */
	public DarkChocolate(String name, double weight, String country, double cocoaButterPercentage, double cocoaSolidsPercentage,
			double sugarPercentage) {
		super(name, weight, country, cocoaButterPercentage, cocoaSolidsPercentage, 0.0, 0.0, sugarPercentage);
	}

	/**
	 * Returns a string describing the dark chocolate
	 * E.g., "Dark chocolate by Mindt, 300 g bar, Switzerland,
	 * 		  Cocoa 85 % 
	 * 		  Sugar 15 %"
	 */
	@Override public String toString() {
		return "Dark Chocolate by " + name +", "+ weight +" g bar, "+country + ", \ncocoa " + (cocoaButterPercentage+cocoaSolidsPercentage)
				+"%, \nsugar " + sugarPercentage + "%\n";
	}

}
