/**
 * This class describes milk chocolate (i.e., chocolate which contains milk in addition to cocoa products)
 * @author Andriyp
 *
 */
public class MilkChocolate extends Chocolate {

	/**
	 * Creates a typical milk chocolate bar with specified name, size, and country
	 * at least 10% cocoa butter, 15 % cocoa solids), 15% total milk solids, and 10% milk fat, 50% sugar. 
	 * @param name Name
	 * @param weight bar size in grams
	 * @param country country of manufacturing
	 */
	public MilkChocolate(String name, double weight, String country){
		this(name, weight, country, 10.0, 15.0, 10.0, 15.0, 50.0);
	}

	/**
	 * Creates a  milk chocolate bar with specified name, size, country and other ingredients
	 * @param name Name
	 * @param weight bar size in grams
	 * @param country country of manufacturing
	 * @param cocoaButterPercentage Percentage of cocoa butter in the chocolate
	 * @param cocoaSolidsPercentage Percentage of cocoa solids in the chocolate
	 * @param milkFat Percentage of milk fat in the chocolate
	 * @param milkSolidsPercentage Percentage Percentage of milk solids in the chocolate
	 * @param sugarPercentage Percentage of sugar in the chocolate
	 */
	public MilkChocolate(String name, double weight, String country, double cocoaButterPercentage, double cocoaSolidsPercentage,
			double milkFat, double milkSolidsPercentage, double sugarPercentage) {
		super(name, weight, country, cocoaButterPercentage, cocoaSolidsPercentage, milkFat, milkSolidsPercentage, sugarPercentage);
	}

	/**
	 * Returns a string describing the milk chocolate
	 * E.g., "Milk chocolate by Badbury, 100 g bar, Canada,
	 * 		  cocoa 25 % 
	 * 		  milk 25 %
	 * 		  sugar 50 %"
	 */
	@Override public String toString() {
		return "Milk Chocolate by " + name +", "+ weight +" g bar, "+country + ", \ncocoa " + (cocoaButterPercentage+cocoaSolidsPercentage)
				+"%, \nmilk " + (milkFatPercentage + milkSolidsPercentage) + "%, \nsugar " + sugarPercentage + "%\n";
	}

}
