/**
 * This class describes white chocolate (i.e., chocolate which contains cocoa butter, but no cocoa solids)
 * @author Andriyp
 *
 */
public class WhiteChocolate extends Chocolate {

	/**
	 * Creates a typical white chocolate bar with specified name, size, and country
	 * at least 20% cocoa butter (0 % cocoa solids), 14% total milk solids, and 3.5% milk fat, and no more than 55% sugar. 
	 * @param name Name
	 * @param weight bar size in grams
	 * @param country country of manufacturing
	 */
	public WhiteChocolate(String name, double weight, String country){
		this(name, weight, country, 20.0, 5.0, 25.0, 50.0);
	}

	/**
	 * Creates a white chocolate bar with specified name, size, country and other ingredients
	 * at least 20% cocoa butter (0 % cocoa solids), 14% total milk solids, and 3.5% milk fat, and no more than 55% sugar. 
	 * @param name Name
	 * @param weight bar size in grams
	 * @param country country of manufacturing
	 * @param cocoaButterPercentage Percentage of cocoa butter in the chocolate
	 * @param milkFat Percentage of milk fat in the chocolate
	 * @param milkSolidsPercentage Percentage Percentage of milk solids in the chocolate
	 * @param sugarPercentage Percentage of sugar in the chocolate
	 */
	public WhiteChocolate(String name, double weight, String country, double cocoaButterPercentage, 
			double milkFat, double milkSolidsPercentage, double sugarPercentage) {
		//the assertions could be used here, but are not mandatory for this test
		super(name, weight, country, cocoaButterPercentage, 0.0, milkFat, milkSolidsPercentage, sugarPercentage);
	}

	/**
	 * Returns a string describing the white chocolate
	 * E.g., "White chocolate by Nersheys, 50 g bar, USA,
	 * 		  cocoa butter 35 % 
	 * 		  milk 20 %
	 * 		  sugar 45 %"
	 */
	@Override public String toString() {
		return "White Chocolate by " + name +", "+ weight +" g bar, "+country + ", \ncocoa butter " + cocoaButterPercentage +"%, \nmilk " 
				+ (milkFatPercentage + milkSolidsPercentage) + "%, \nsugar " + sugarPercentage + "%\n";
	}

}
